<div class="row d-flex justify-content-between align-items-center submodule" id="overview-container">
    <div class="col-4">
        <div class="card text-white" id="progress-card">
            <div class="card-header text-center">Found / Scanned / Total</div>
            <div class="card-body text-center">
                {{ data.devices_alive }} / {{ data.devices_scanned }} / {{ data.devices_total }}
            </div>
        </div>
    </div>
    <div class="col-4">
        <div class="card text-white overview-card" id="runtime-card">
            <div class="card-header text-center">Runtime</div>
            <div class="card-body text-center">
                {{ data.run_time }}s
            </div>
        </div>
    </div>
    <div class="col-4">
        <div class="card text-white overview-card" id="stage-card">
            <div class="card-header text-center">Stage</div>
            <div class="card-body text-center">
                {{ data.stage }}
            </div>
        </div>
    </div>
</div>
